#!/usr/bin/python
# -*- coding: utf-8 -*-
##################################################################################
##    PSFreedom UI for the N900, UI to easily jailbreak the PS3                 ##
##    Copyright (C) 2010 Mohammad Abu-Garbeyyeh                                 ##
##                  2010 Youness Alaoui (modules used in the application)       ##
##                  2010 Mobashir Ahmed (Graphics used in application)          ##
##                                                                              ##
##    This program is free software; you can redistribute it and/or modify      ##
##    it under the terms of the GNU General Public License as published by      ##
##    the Free Software Foundation; either version 2 of the License, or         ##
##    (at your option) any later version.                                       ##
##                                                                              ##
##    This program is distributed in the hope that it will be useful,           ##
##    but WITHOUT ANY WARRANTY; without even the implied warranty of            ##
##    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             ##
##    GNU General Public License for more details.                              ##
##                                                                              ##
##    You should have received a copy of the GNU General Public License         ##
##    along with this program; if not, write to the Free Software               ##
##    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA ##
##################################################################################

print "Importing PyQt4 modules"
from PyQt4 import QtCore, QtGui
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from PyQt4.QtWebKit import *
print "Importing sys"
import sys
print "Importing os"
import os
print "Importing dbus"
import dbus

# This should disable selection in QWebView, at the moment it doesn't, for some reason...
class QWebViewSelectionSuppressor(QObject):
    
    def __init__(self, view, *args, **kwargs):
        super(QWebViewSelectionSuppressor, self).__init__(*args, **kwargs)
        
        self.enabled = False
        self.mousePressed = False
        self.view = view
        
        self.enable()
        
    def enable(self):
        if self.enabled:
            return
        self.view.installEventFilter(self)
        self.enabled = True
        
    def disable(self):
        if not self.enabled:
            return
        self.view.removeEventFilter(self)
        self.enabled = False
        
    def isEnabled(self):
        return self.enabled
        
    def eventFilter(self, object, e):
        if e.type() == QEvent.MouseButtonPress:
            if e.button() == Qt.LeftButton:
                self.mousePressed = True
        elif e.type() == QEvent.MouseButtonRelease:
            if e.button() == Qt.LeftButton:
                self.mousePressed = False
        elif e.type() == QEvent.MouseMove:
            if self.mousePressed:
                return True
        return False


class MainWindow(QtGui.QMainWindow):
    
    def __init__(self, parent):
        QtGui.QMainWindow.__init__(self)

        self.setAttribute(Qt.WA_Maemo5StackedWindow)
        self.setObjectName("MainWindow")
        self.setStyleSheet("MainWindow { background-image: url(/opt/psfreedom/resources/images/psfreedombg.png); }")
        self.setWindowTitle("PSFreedom")
	# App top menu bar buttons.
        self.menubar = self.menuBar().addMenu("Menu")
        self.aboutAction = self.menubar.addAction("About")
        self.aboutQtAction = self.menubar.addAction("About Qt")
	self.showLogs = self.menubar.addAction("Kernel messages")
	self.help = self.menubar.addAction("Help")
#       self.portrait = self.menubar.addAction("Portrait")
	# Labels.
	MainWindow.labeldisabled = QtGui.QLabel(self)
	MainWindow.labeldisabled.setGeometry(QtCore.QRect(510, 395, 391, 20))
	MainWindow.labeldisabled.setObjectName("label")
	MainWindow.labeldisabled.setText(QtGui.QApplication.translate("MainWindow", "PSFreedom status: Disabled", None, QtGui.QApplication.UnicodeUTF8))
	MainWindow.labeldisabled.hide()
	MainWindow.labelenabled = QtGui.QLabel(self)
	MainWindow.labelenabled.setGeometry(QtCore.QRect(510, 395, 391, 20))
	MainWindow.labelenabled.setObjectName("label")
	MainWindow.labelenabled.setText(QtGui.QApplication.translate("MainWindow", "PSFreedom status: Enabled", None, QtGui.QApplication.UnicodeUTF8))
        MainWindow.labelenabled.hide()
	MainWindow.labelbdemudisabled = QtGui.QLabel(self)
	MainWindow.labelbdemudisabled.setGeometry(QtCore.QRect(510, 395, 391, 20))
	MainWindow.labelbdemudisabled.setObjectName("label")
	MainWindow.labelbdemudisabled.setText(QtGui.QApplication.translate("MainWindow", "BD Emulation disabled", None, QtGui.QApplication.UnicodeUTF8))
	MainWindow.labelbdemuenabled = QtGui.QLabel(self)
	MainWindow.labelbdemuenabled.setGeometry(QtCore.QRect(510, 395, 391, 20))
	MainWindow.labelbdemuenabled.setObjectName("label")
	MainWindow.labelbdemuenabled.setText(QtGui.QApplication.translate("MainWindow", "BD Emulation enabled", None, QtGui.QApplication.UnicodeUTF8))
	MainWindow.labelbdemudisabled.hide()
	MainWindow.labelbdemuenabled.hide()
	# Buttons
        self.button1 = QtGui.QPushButton("Jailbreak mode on", self)
        self.button1.setObjectName("button1")
        self.button1.setGeometry(QtCore.QRect(200, 220, 447, 70))
	self.button1.show()
        self.button2 = QtGui.QPushButton("Jailbreak mode off", self)
        self.button2.setObjectName("button2")
	self.button2.setGeometry(QtCore.QRect(200, 220, 447, 70))
	self.button2.hide()
	MainWindow.button3 = QtGui.QPushButton("Enable BD emu", self)
	MainWindow.button3.setGeometry(QtCore.QRect(290, 300, 247, 50))
	MainWindow.button3.hide()
	MainWindow.button4 = QtGui.QPushButton("Disable BD emu", self)
	MainWindow.button4.setGeometry(QtCore.QRect(290, 300, 247, 50))
	MainWindow.button4.hide()
	self.checkmodulestatus()
#	self.payload_list = QtGui.QComboBox(self)
#	self.payload_list.setGeometry(QtCore.QRect(300, 320, 190, 45))
#	self.payload_list.addItem("payload_bdemu.bin")
#	self.payload_list.addItem("payload_no_bdemu.bin")

        self.layout = QtGui.QVBoxLayout()
        self.setLayout(self.layout)

	# Connecting buttons and menu items.
	QtCore.QObject.connect(self.button1, QtCore.SIGNAL("clicked()"), self.jailbreakon)
	QtCore.QObject.connect(self.button2, QtCore.SIGNAL("clicked()"), self.jailbreakoff)
	QtCore.QObject.connect(self.button3, QtCore.SIGNAL("clicked()"), self.enablebdemu)
	QtCore.QObject.connect(self.button4, QtCore.SIGNAL("clicked()"), self.disablebdemu)
	QtCore.QObject.connect(self.aboutAction, QtCore.SIGNAL("triggered()"), self.about)
	QtCore.QObject.connect(self.aboutQtAction, QtCore.SIGNAL("triggered()"), self.aboutQt)
	QtCore.QObject.connect(self.showLogs, QtCore.SIGNAL("triggered()"), self.logs)
	QtCore.QObject.connect(self.help, QtCore.SIGNAL("triggered()"), self.helpafterrun)
#      QtCore.QObject.connect(self.portrait, QtCore.SIGNAL("triggered()"), self.portraitmode)

    def enablebdemu(self):
	MainWindow.button3.hide()
	MainWindow.button4.show()
	os.popen("/opt/psfreedom/resources/scripts/helperscript.sh --enablebdemu")
	MainWindow.labelbdemudisabled.hide()
	MainWindow.labelbdemuenabled.show()
	bus = dbus.SystemBus()
        iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
                                              '/org/freedesktop/Notifications'),
                                              'org.freedesktop.Notifications')
        iface.SystemNoteInfoprint("BD Emulation enabled.")

    def disablebdemu(self):
	MainWindow.button3.show()
	MainWindow.button4.hide()
	os.popen("/opt/psfreedom/resources/scripts/helperscript.sh --disablebdemu")
	MainWindow.labelbdemuenabled.hide()
	MainWindow.labelbdemudisabled.show()
	bus = dbus.SystemBus()
        iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
                                              '/org/freedesktop/Notifications'),
                                              'org.freedesktop.Notifications')
        iface.SystemNoteInfoprint("BD Emulation disabled.")


    def checkmodulestatus(self):
	if os.path.isfile("/proc/psfreedom/status"):
		self.button1.hide()
		self.button2.show()
		MainWindow.labelenabled.setGeometry(QtCore.QRect(510, 365, 391, 20))
		MainWindow.labelenabled.show()
		MainWindow.labeldisabled.hide()
		payload = os.popen("cat /proc/psfreedom/payload | grep dev").read()
		payloadstripped = str(payload).strip()
		if str(payloadstripped) == "/dev_bdvd":
			MainWindow.button4.show()
			MainWindow.button3.hide()
			MainWindow.labelbdemudisabled.hide()
			MainWindow.labelbdemuenabled.show()
		else:
			MainWindow.button4.hide()
			MainWindow.button3.show()
			MainWindow.labelbdemuenabled.hide()
			MainWindow.labelbdemudisabled.show()
	else:
		self.button1.show()
		self.button2.hide()
		MainWindow.labelenabled.hide()
		MainWindow.labeldisabled.show()
		

#   Portrait mode, experimental, disabled in the GUI at the moment.
    def portraitmode(self):
        self.resize(480, 800)
        self.setAttribute(Qt.WA_Maemo5PortraitOrientation)
        self.button1.setGeometry(QtCore.QRect(20, 400, 447, 70))
        self.button2.setGeometry(QtCore.QRect(20, 400, 447, 70))
	MainWindow.labeldisabled.setGeometry(QtCore.QRect(0, 720, 391, 20))
	MainWindow.labelenabled.setGeometry(QtCore.QRect(0, 720, 391, 20))
        logdialog.resize(480, 800)
        res = 480, 800
#	MainWindow.labeldisabled.setGeometry(QtCore.QRect(0, 750, 391, 20))       

#   Check if first run, if yes, show help window with steps needed to jailbreak, if not, do nothing
    def firstrun(self):
	if os.path.isfile("/home/user/.psfreedom_ran"):
		print "PSFreedom started before, not auto-popping up help dialog"
	else: 
		os.popen("touch /home/user/.psfreedom_ran && chown user:users /home/user/.psfreedom_ran")
		self.helpafterrun()
		bus = dbus.SystemBus()
        	iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
        	                                      '/org/freedesktop/Notifications'),
        	                                      'org.freedesktop.Notifications')
       		iface.SystemNoteInfoprint("PSFreedom has detected that this is the first run.")

#   kernel messages
    def logs(self):
        logdialog = QtGui.QMainWindow(self)
        logdialog.setAttribute(Qt.WA_Maemo5StackedWindow)
        logdialog.setWindowTitle('Kernel Messages')
        logdialog.show()
	logdialog.textBrowser = QtGui.QTextBrowser(logdialog)
	logdialog.textBrowser.setGeometry(QtCore.QRect(0, 10, 800, 440))
	# Thanks DocScrutinizer! :)
	fsock = os.popen("dmesg | grep PSFreedom* | sed 's/$/\<br\>/'").read()
	logdialog.textBrowser.setHtml(fsock)
	font = QtGui.QFont()
	font.setPointSize(16)
	logdialog.textBrowser.setFont(font)
	logdialog.textBrowser.show()
        logdialog.menubar = logdialog.menuBar().addMenu("Submenu")
        logdialog.saveLogs = logdialog.menubar.addAction("Export")
	QtCore.QObject.connect(logdialog.saveLogs, QtCore.SIGNAL("triggered()"), self.savelogs)

#   kernel messages - export
    def savelogs(self):
	os.popen("dmesg | grep PSFreedom* > /home/user/MyDocs/PSFreedom.txt")
	bus = dbus.SystemBus()
        iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
                                              '/org/freedesktop/Notifications'),
                                              'org.freedesktop.Notifications')
        iface.SystemNoteInfoprint("Saved to /home/user/MyDocs/PSFreedom.txt")

	#self.help1 = QtGui.QMessageBox.information(None, "PSFreedom - Help","To jailbreak your PS3:\n\n1. Flip the back switch on the PS3 to off or remove the power cable.\n2. Connect the N900 to the PS3.\n3. Flip the switch back to on again.\n4. Press the power button on the PS3 then quickly press the eject button.\n5. Check kernel messages (top bar) to see if the jailbreak succeeded.\nNote: at the moment, this works on FW 3.41 only.")
#######################################################################################

#   Help dialog without first run stuff
    def helpafterrun(self):
	MainWindow.helpWin = QtGui.QMainWindow(self)
	MainWindow.helpWin.setAttribute(Qt.WA_Maemo5StackedWindow)
	image = QtGui.QPixmap("/opt/psfreedom/resources/helpimages/Version/version.png")
	MainWindow.modellabel = QtGui.QLabel(MainWindow.helpWin)
	MainWindow.modellabel.setPixmap(image)
	MainWindow.modellabel.resize(800, 430)
	MainWindow.modellabel.setScaledContents(True)
	MainWindow.modellabel.show()
	MainWindow.buttonphat = QtGui.QPushButton("Phat", MainWindow.helpWin)
        MainWindow.buttonphat.setGeometry(QtCore.QRect(500, 100, 200, 70))
	QtCore.QObject.connect(MainWindow.buttonphat, QtCore.SIGNAL("clicked()"), self.phatpages)
	MainWindow.buttonslim = QtGui.QPushButton("Slim", MainWindow.helpWin)
        MainWindow.buttonslim.setGeometry(QtCore.QRect(120, 100, 200, 70))
	QtCore.QObject.connect(MainWindow.buttonslim, QtCore.SIGNAL("clicked()"), self.slimpages)
	MainWindow.helpWin.setWindowTitle("PSFreedom - Help")
	MainWindow.helpWin.show()

    def slimpages(self):
	os.popen("sudo /opt/psfreedom/resources/helpimages/modelimages.sh --slim")
	self.help_page1()

    def phatpages(self):
	os.popen("sudo /opt/psfreedom/resources/helpimages/modelimages.sh --phat")
	self.help_page1()
	
    def help_page1(self):
	image = QtGui.QPixmap("/opt/psfreedom/resources/helpimages/page1.png")
	MainWindow.page1label = QtGui.QLabel(MainWindow.helpWin)
	MainWindow.page1label.setPixmap(image)
	MainWindow.page1label.resize(800, 430)
	MainWindow.page1label.setScaledContents(True)
	MainWindow.page1label.show()
        MainWindow.buttonnextpage1 = QtGui.QPushButton("Next", MainWindow.helpWin)
        MainWindow.buttonnextpage1.setObjectName("buttonnextpage1")
        MainWindow.buttonnextpage1.setGeometry(QtCore.QRect(650, 0, 150, 70))
	QtCore.QObject.connect(MainWindow.buttonnextpage1, QtCore.SIGNAL("clicked()"), self.help_page2)
	MainWindow.buttonnextpage1.show()

    def help_page2(self):
	MainWindow.page1label.destroy()
	image = QtGui.QPixmap("/opt/psfreedom/resources/helpimages/page2.png")
	MainWindow.page2label = QtGui.QLabel(MainWindow.helpWin)
	MainWindow.page2label.setPixmap(image)
	MainWindow.page2label.resize(800, 430)
	MainWindow.page2label.setScaledContents(True)
	MainWindow.page2label.show()
	# Next button on page 2
        MainWindow.buttonnextpage2 = QtGui.QPushButton("Next", MainWindow.helpWin)
        MainWindow.buttonnextpage2.setObjectName("buttonnextpage2")
        MainWindow.buttonnextpage2.setGeometry(QtCore.QRect(650, 0, 150, 70))
	QtCore.QObject.connect(MainWindow.buttonnextpage2, QtCore.SIGNAL("clicked()"), self.help_page3)
	MainWindow.buttonnextpage2.show()
	# Previous button on page 2
        MainWindow.buttonprevpage2 = QtGui.QPushButton("Previous", MainWindow.helpWin)
        MainWindow.buttonprevpage2.setObjectName("buttonprevpage2")
        MainWindow.buttonprevpage2.setGeometry(QtCore.QRect(0, 0, 150, 70))
	QtCore.QObject.connect(MainWindow.buttonprevpage2, QtCore.SIGNAL("clicked()"), self.help_page1)
	MainWindow.buttonprevpage2.show()

    def help_page3(self):
	MainWindow.page1label.destroy()
	image = QtGui.QPixmap("/opt/psfreedom/resources/helpimages/page3.png")
	MainWindow.page3label = QtGui.QLabel(MainWindow.helpWin)
	MainWindow.page3label.setPixmap(image)
	MainWindow.page3label.resize(800, 430)
	MainWindow.page3label.setScaledContents(True)
	MainWindow.page3label.show()
	# Next button on page 3
        MainWindow.buttonnextpage3 = QtGui.QPushButton("Next", MainWindow.helpWin)
        MainWindow.buttonnextpage3.setObjectName("buttonnextpage3")
        MainWindow.buttonnextpage3.setGeometry(QtCore.QRect(650, 0, 150, 70))
	QtCore.QObject.connect(MainWindow.buttonnextpage3, QtCore.SIGNAL("clicked()"), self.help_page4)
	MainWindow.buttonnextpage3.show()
	# Previous button on page 3
        MainWindow.buttonprevpage3 = QtGui.QPushButton("Previous", MainWindow.helpWin)
        MainWindow.buttonprevpage3.setObjectName("buttonprevpage3")
        MainWindow.buttonprevpage3.setGeometry(QtCore.QRect(0, 0, 150, 70))
	QtCore.QObject.connect(MainWindow.buttonprevpage3, QtCore.SIGNAL("clicked()"), self.help_page2)
	MainWindow.buttonprevpage3.show()

    def help_page4(self):
	MainWindow.page1label.destroy()
	image = QtGui.QPixmap("/opt/psfreedom/resources/helpimages/page4.png")
	MainWindow.page4label = QtGui.QLabel(MainWindow.helpWin)
	MainWindow.page4label.setPixmap(image)
	MainWindow.page4label.resize(800, 430)
	MainWindow.page4label.setScaledContents(True)
	MainWindow.page4label.show()
	# Next button on page 4
        MainWindow.buttonnextpage4 = QtGui.QPushButton("Next", MainWindow.helpWin)
        MainWindow.buttonnextpage4.setObjectName("buttonnextpage3")
        MainWindow.buttonnextpage4.setGeometry(QtCore.QRect(650, 0, 150, 70))
	QtCore.QObject.connect(MainWindow.buttonnextpage4, QtCore.SIGNAL("clicked()"), self.help_page5)
	MainWindow.buttonnextpage4.show()
	# Previous button on page 4
        MainWindow.buttonprevpage4 = QtGui.QPushButton("Previous", MainWindow.helpWin)
        MainWindow.buttonprevpage4.setObjectName("buttonprevpage4")
        MainWindow.buttonprevpage4.setGeometry(QtCore.QRect(0, 0, 150, 70))
	QtCore.QObject.connect(MainWindow.buttonprevpage4, QtCore.SIGNAL("clicked()"), self.help_page3)
	MainWindow.buttonprevpage4.show()

    def help_page5(self):
	MainWindow.page1label.destroy()
	image = QtGui.QPixmap("/opt/psfreedom/resources/helpimages/page5.png")
	MainWindow.page5label = QtGui.QLabel(MainWindow.helpWin)
	MainWindow.page5label.setPixmap(image)
	MainWindow.page5label.resize(800, 430)
	MainWindow.page5label.setScaledContents(True)
	MainWindow.page5label.show()
	# Previous button on page 5
        MainWindow.buttonprevpage5 = QtGui.QPushButton("Previous", MainWindow.helpWin)
        MainWindow.buttonprevpage5.setObjectName("buttonprevpage5")
        MainWindow.buttonprevpage5.setGeometry(QtCore.QRect(0, 0, 150, 70))
	QtCore.QObject.connect(MainWindow.buttonprevpage5, QtCore.SIGNAL("clicked()"), self.help_page4)
	MainWindow.buttonprevpage5.show()
        MainWindow.kernellogs = QtGui.QPushButton("Kernel messages", MainWindow.helpWin)
        MainWindow.kernellogs.setObjectName("kernellogs")
	MainWindow.kernellogs.setGeometry(QtCore.QRect(180, 180, 500, 70))
	QtCore.QObject.connect(MainWindow.kernellogs, QtCore.SIGNAL("clicked()"), self.logqdialog)
	MainWindow.kernellogs.show()

    def logqdialog(self):
	dialog = QtGui.QDialog(self)
	dialog.resize(800, 420)
	dialog.setWindowTitle("PSFreedom - Kernel Messages")
	dialog.textBrowser = QtGui.QTextBrowser(dialog)
	dialog.textBrowser.setGeometry(QtCore.QRect(0, 0, 800, 320))
	# Thanks DocScrutinizer! :)
	fsock = os.popen("dmesg | grep PSFreedom* | sed 's/$/\<br\>/'").read()
	dialog.textBrowser.setHtml(fsock)
	font = QtGui.QFont()
	font.setPointSize(16)
	dialog.textBrowser.setFont(font)
	dialog.textBrowser.show()
        MainWindow.dialogexport = QtGui.QPushButton("Export", dialog)
        MainWindow.dialogexport.setObjectName("dialogbuttonexport")
        MainWindow.dialogexport.setGeometry(QtCore.QRect(0, 330, 800, 50))
	QtCore.QObject.connect(MainWindow.dialogexport, QtCore.SIGNAL("clicked()"), self.savelogs)
	MainWindow.dialogexport.show()
	dialog.show()

#######################################################################################

#   About Qt
    def aboutQt(self):
	self.AboutDialog = QtGui.QMessageBox.aboutQt(None)

#   About window
    def about(self):
        aboutWin = QtGui.QMainWindow(self)
        aboutWin.setAttribute(Qt.WA_Maemo5StackedWindow)
        aboutWin.setWindowTitle('About PSFreedom')
	aboutWin.resize(800, 480)
        aboutWin.show()
# ============ Old about screen, works but is minimal, uncommenting this and commenting what's below switches screens.====
#	aboutWin.textBrowser = QtGui.QTextBrowser(aboutWin)
#	aboutWin.textBrowser.setGeometry(QtCore.QRect(0, 10, 800, 460))
#	aboutWin.textBrowser.setOpenExternalLinks(True)
#	fsock = os.popen('cat /opt/psfreedom/resources/aboutpsfreedom.html').read()
#	aboutWin.textBrowser.setHtml(fsock)
#	font = QtGui.QFont()
#	font.setPointSize(20)
#	aboutWin.textBrowser.setFont(font)
#	aboutWin.textBrowser.show()
# =========================================================================================================================
	web = QWebView(aboutWin)
	web.load(QUrl("file:///opt/psfreedom/resources/aboutpsfreedom.html"))
	web.setGeometry(QtCore.QRect(0, 0, 800, 460))
        suppressor = QWebViewSelectionSuppressor(web)
        suppressor.enable()
        scroller = web.property("kineticScroller").toPyObject()
        scroller.setEnabled(True)
	web.show()

#   Jailbreak on button function
    def jailbreakon(self):
	os.popen("sudo /usr/sbin/psfreedom-enable-n900.sh")
	self.button1.hide()
	self.button2.show()
	MainWindow.labeldisabled.hide()
	MainWindow.labelenabled.show()
        bus = dbus.SystemBus()
        iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
                                              '/org/freedesktop/Notifications'),
                                              'org.freedesktop.Notifications')
        iface.SystemNoteInfoprint("Jailbreak mode enabled")
	MainWindow.button3.show()
	MainWindow.labelenabled.setGeometry(QtCore.QRect(510, 365, 391, 20))
	MainWindow.labelbdemudisabled.show()
	self.firstrun()

#   Jailbreak off button function
    def jailbreakoff(self):
	os.popen("sudo /usr/sbin/psfreedom-disable-n900.sh")
	self.button2.hide()
	self.button1.show()
	MainWindow.labelenabled.hide()
	MainWindow.labeldisabled.show()
	self.disablebdemu()
        bus = dbus.SystemBus()
        iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
                                              '/org/freedesktop/Notifications'),
                                              'org.freedesktop.Notifications')
        iface.SystemNoteInfoprint("Jailbreak mode disabled")
	MainWindow.button3.hide()
	MainWindow.button4.hide()
	MainWindow.labelbdemudisabled.hide()
	MainWindow.labelbdemuenabled.hide()


# Starting up the app
if __name__ == "__main__":
	app = QtGui.QApplication(sys.argv)
	mainWindow = MainWindow(None)
	mainWindow.show()
	sys.exit(app.exec_())
